# 'pptestgosiaprzybysz' - my simple first project on PyPi

* Op1
* Op2
* Op3

# Install

'''python
pip install pptestgosiaprzybysz
'''

### Usage
'''python
from pptestgosiaprzybysz.m_mod_pptest import name as n

>>> n("Name", "Surname")
Witaj: Name Surname
>>> get_numpy_arr([1, 2, 3, 4, 5])
[1 2 3 4 5]
'''